@@ -196,7 +196,7 @@ class CoordinatesDisplacement(object):
             
         return self.enu
 
-    def __abs__(self):
+    def __abs__(self) -> float:
         """
         >>> c = CoordinatesDisplacement.from_xyz(0.1, 0.1, 0.1)
         >>> f'{abs(c):.4f}'
