@@ -5,6 +5,7 @@ import math
 WeekTow = namedtuple('WeekTow', 'week tow day_of_week')
 
 GPS_TIME_START = datetime.datetime(1980, 1, 6, 0, 0, 0)
+J2000_TIME_START = datetime.datetime(2000, 1, 1, 12, 0, 0)
 SECONDS_IN_DAY = 24 * 60 * 60
 SECONDS_IN_WEEK = 86400 * 7
 GPS_AS_J2000 = -630763200
@@ -86,6 +87,22 @@ def to_j2000(epoch: datetime.datetime) -> float:
     week_tow = to_week_tow(epoch)
     return weektow_to_j2000(week_tow.tow, week_tow.week)
 
+def from_j2000(j2000s: int, fraction_of_seconds: float = 0.0):
+    """
+    Convert from J2000 epoch to datetime
+
+    >>> from_j2000(160191000)
+    datetime.datetime(2005, 1, 28, 13, 30)
+
+    >>> from_j2000(160191000, fraction_of_seconds = 0.1)
+    datetime.datetime(2005, 1, 28, 13, 30, 0, 100000)
+    """
+
+    microseconds = int(fraction_of_seconds * 1.0e6)
+    epoch = J2000_TIME_START + datetime.timedelta(seconds=j2000s, microseconds=microseconds)
+
+    return epoch
+
 
 def epoch_range(start_epoch, end_epoch, interval_s):
     """
